/**
*  A test driver for the limited demo of the CreditCard package.
*
*  This code should give you a basic idea of how the full package works.
*  The demo class will only recognize VISA cards.  The full version
*  identifies VISA, MasterCard, AMEX, Diners Club, Discover, JCB, and enRoute.
*
*  For additional information, to see the full documentation, or to purchase
*  the fully functional package, please visit
*  http://products.dmmw.com
*
*  Copyright (c) 2002 - DMMW - All rights reserved.
*/

class ConsoleTest {
	public static void main(String[] args) {
		if (args.length == 0) {
			System.out.println("\nUsage:  java ConsoleTest <card_number>\n");
			System.out.println("Demo of the Credit Card Verification package.\n");
			System.out.println("This demo uses a subset of the actual package com.dmmw.financial.CreditCard");
			System.out.println("In this demo only VISA cards are verified.  All other card types will be");
			System.out.println("returned as type unknown.\n");
			System.out.println("To see the documentation of the full package, or to purchase, please");
			System.out.println("visit:  http://products.dmmw.com\n");
			System.exit(0);
		} 

		CreditCard card = new CreditCard(args[0]);
		card.resetErrorCode();
		
		if (card.hasNoInvalidChars()) {
			if ((card.getCardType() & CreditCard.TYPE_VISA) == CreditCard.TYPE_VISA) {
				if (card.LuhnCheck()) {
					System.out.println("The Card Number appears to be OK.");
					System.exit(1);
				}
			}	
		} 
		
		// Now lets handle any errors (this is not the best coding but it is easy to read).
		int error = card.getLastErrorCode();

		System.out.println("Oh Oh, the card appears to be invalid:");
		if ((error & CreditCard.ERROR_UNRECOGNIZED_CARD_TYPE) == CreditCard.ERROR_UNRECOGNIZED_CARD_TYPE) {
			System.out.println("\tError: Unrecognized card type.");
		}
		if ((error & CreditCard.ERROR_FAILED_LUHN_CHECK) == CreditCard.ERROR_FAILED_LUHN_CHECK) {
			System.out.println("\tError: Card number failed the Luhn check.");
		}
		if ((error & CreditCard.ERROR_WRONG_LENGTH) == CreditCard.ERROR_WRONG_LENGTH) {
			System.out.println("\tError: Card number has the wrong length.");
		}
		if ((error & CreditCard.ERROR_INVALID_CHARS) ==  CreditCard.ERROR_INVALID_CHARS) {
			System.out.println("\tError: Card number has at least one invalid character.");
		}
	}
}